# PYGatewayListener

PYGatewayListener is a functional Python 3 script with library capable for dealing with Serial data inflows and its corresponding reactive actions.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install PYGatewayListener.

```bash
pip3 install pyserialgateway
```

## Usage

Directly run the installed package as-is for quick run, if not, import the package to utilise its functions.

```python
python3 pygw_main.py [args...]

For full help:
pip3 show pyserialgateway
or
python3 pygw_main.py [-h,--help]
```

## Contributing
For major changes, please open an issue first to discuss what you would like to change.


## License
[MIT](https://choosealicense.com/licenses/mit/)